---
icon: "material/table"
---


Generates a summary of the predicates used in all the included encodings.


The definition is taken from the [predicate documentation](#predicate-documentation) ,
and the type indicates the following:


| Title                  | Icon                                                                 |
|------------------------|----------------------------------------------------------------------|
| Input (Not defined by any rule)                  | <span style="color:#9178C6; padding-top: 0; padding-bottom: 0;" title="Input" class="twemoji">:material-arrow-right-bold:</span> |
| Shown                  | <span style="color:#52BF54; padding-top: 0; padding-bottom: 0;" title="Shown" class="twemoji">:material-eye:</span> |
| Shown Explicitly (using `predicate/arity`)      | <span style="color:#52BF54; padding-top: 0; padding-bottom: 0;" title="Shown Explicitly" class="twemoji">:material-eye:</span> |
| Shown Partially (using a conditional statement)       | <span style="color:#52BF54; padding-top: 0; padding-bottom: 0;" title="Shown Partially" class="twemoji">:material-eye-plus:</span> |
| Hidden                 | <span style="color:#88888850; padding-top: 0; padding-bottom: 0;" title="Hidden" class="twemoji">:material-eye-off:</span> |


!!! example


    === "Usage"

        ```
        ::: examples/sudoku/encoding.lp
            handler: asp
            options:
                predicate_table: true
                start_level: 3
        ```

    === "Output"

        ::: examples/sudoku/encoding.lp
            handler: asp
            options:
                predicate_table: true
                start_level: 3


## Configuration options

- `ignore-includes` Boolean indication that the included files should not be counted for the predicates. By default all included files used when gathering predicates. (TODO)

<!--
## IDEAS

- The definition could be a summary of the documentation generated by an LLM
 -->
